@@ -108,7 +108,7 @@ class whatever(object):
 
 
 def _extend_string_class(class_node, code, rvalue):
-    """function to extend builtin str/unicode class"""
+    """Function to extend builtin str/unicode class."""
     code = code.format(rvalue=rvalue)
     fake = AstroidBuilder(AstroidManager()).string_build(code)["whatever"]
     for method in fake.mymethods():
@@ -135,7 +135,7 @@ _extend_builtins(
 )
 
 
-def _builtin_filter_predicate(node, builtin_name):
+def _builtin_filter_predicate(node, builtin_name) -> bool:
     if (
         builtin_name == "type"
         and node.root().name == "re"
@@ -164,14 +164,14 @@ def _builtin_filter_predicate(node, builtin_name):
     return False
 
 
-def register_builtin_transform(transform, builtin_name):
+def register_builtin_transform(transform, builtin_name) -> None:
     """Register a new transform function for the given *builtin_name*.
 
     The transform function must accept two parameters, a node and
     an optional context.
     """
 
-    def _transform_wrapper(node, context=None):
+    def _transform_wrapper(node, context: InferenceContext | None = None):
         result = transform(node, context=context)
         if result:
             if not result.parent:
@@ -336,7 +336,7 @@ def _get_elts(arg, context):
     return items
 
 
-def infer_dict(node, context=None):
+def infer_dict(node, context: InferenceContext | None = None):
     """Try to infer a dict call to a Dict node.
 
     The function treats the following cases:
@@ -379,7 +379,7 @@ def infer_dict(node, context=None):
     return value
 
 
-def infer_super(node, context=None):
+def infer_super(node, context: InferenceContext | None = None):
     """Understand super calls.
 
     There are some restrictions for what can be understood:
@@ -458,8 +458,8 @@ def _infer_getattr_args(node, context):
     return obj, attr.value
 
 
-def infer_getattr(node, context=None):
-    """Understand getattr calls
+def infer_getattr(node, context: InferenceContext | None = None):
+    """Understand getattr calls.
 
     If one of the arguments is an Uninferable object, then the
     result will be an Uninferable object. Otherwise, the normal attribute
@@ -486,8 +486,8 @@ def infer_getattr(node, context=None):
     raise UseInferenceDefault
 
 
-def infer_hasattr(node, context=None):
-    """Understand hasattr calls
+def infer_hasattr(node, context: InferenceContext | None = None):
+    """Understand hasattr calls.
 
     This always guarantees three possible outcomes for calling
     hasattr: Const(False) when we are sure that the object
@@ -513,8 +513,8 @@ def infer_hasattr(node, context=None):
     return nodes.Const(True)
 
 
-def infer_callable(node, context=None):
-    """Understand callable calls
+def infer_callable(node, context: InferenceContext | None = None):
+    """Understand callable calls.
 
     This follows Python's semantics, where an object
     is callable if it provides an attribute __call__,
@@ -538,7 +538,7 @@ def infer_callable(node, context=None):
 def infer_property(
     node: nodes.Call, context: InferenceContext | None = None
 ) -> objects.Property:
-    """Understand `property` class
+    """Understand `property` class.
 
     This only infers the output of `property`
     call, not the arguments themselves.
@@ -571,7 +571,7 @@ def infer_property(
     return prop_func
 
 
-def infer_bool(node, context=None):
+def infer_bool(node, context: InferenceContext | None = None):
     """Understand bool calls."""
     if len(node.args) > 1:
         # Invalid bool call.
@@ -594,7 +594,7 @@ def infer_bool(node, context=None):
     return nodes.Const(bool_value)
 
 
-def infer_type(node, context=None):
+def infer_type(node, context: InferenceContext | None = None):
     """Understand the one-argument form of *type*."""
     if len(node.args) != 1:
         raise UseInferenceDefault
@@ -602,7 +602,7 @@ def infer_type(node, context=None):
     return helpers.object_type(node.args[0], context)
 
 
-def infer_slice(node, context=None):
+def infer_slice(node, context: InferenceContext | None = None):
     """Understand `slice` calls."""
     args = node.args
     if not 0 < len(args) <= 3:
@@ -629,14 +629,14 @@ def infer_slice(node, context=None):
     return slice_node
 
 
-def _infer_object__new__decorator(node, context=None):
+def _infer_object__new__decorator(node, context: InferenceContext | None = None):
     # Instantiate class immediately
     # since that's what @object.__new__ does
     return iter((node.instantiate_class(),))
 
 
-def _infer_object__new__decorator_check(node):
-    """Predicate before inference_tip
+def _infer_object__new__decorator_check(node) -> bool:
+    """Predicate before inference_tip.
 
     Check if the given ClassDef has an @object.__new__ decorator
     """
@@ -650,8 +650,8 @@ def _infer_object__new__decorator_check(node):
     return False
 
 
-def infer_issubclass(callnode, context=None):
-    """Infer issubclass() calls
+def infer_issubclass(callnode, context: InferenceContext | None = None):
+    """Infer issubclass() calls.
 
     :param nodes.Call callnode: an `issubclass` call
     :param InferenceContext context: the context for the inference
@@ -693,12 +693,10 @@ def infer_issubclass(callnode, context=None):
     return nodes.Const(issubclass_bool)
 
 
-def infer_isinstance(callnode, context=None):
-    """Infer isinstance calls
+def infer_isinstance(callnode, context: InferenceContext | None = None):
+    """Infer isinstance calls.
 
     :param nodes.Call callnode: an isinstance call
-    :param InferenceContext context: context for call
-        (currently unused but is a common interface for inference)
     :rtype nodes.Const: Boolean Const value of isinstance call
 
     :raises UseInferenceDefault: If the node cannot be inferred
@@ -732,7 +730,7 @@ def infer_isinstance(callnode, context=None):
     return nodes.Const(isinstance_bool)
 
 
-def _class_or_tuple_to_container(node, context=None):
+def _class_or_tuple_to_container(node, context: InferenceContext | None = None):
     # Move inferences results into container
     # to simplify later logic
     # raises InferenceError if any of the inferences fall through
@@ -757,8 +755,8 @@ def _class_or_tuple_to_container(node, context=None):
     return class_container
 
 
-def infer_len(node, context=None):
-    """Infer length calls
+def infer_len(node, context: InferenceContext | None = None):
+    """Infer length calls.
 
     :param nodes.Call node: len call to infer
     :param context.InferenceContext: node context
@@ -780,8 +778,8 @@ def infer_len(node, context=None):
         raise UseInferenceDefault(str(exc)) from exc
 
 
-def infer_str(node, context=None):
-    """Infer str() calls
+def infer_str(node, context: InferenceContext | None = None):
+    """Infer str() calls.
 
     :param nodes.Call node: str() call to infer
     :param context.InferenceContext: node context
@@ -796,8 +794,8 @@ def infer_str(node, context=None):
         raise UseInferenceDefault(str(exc)) from exc
 
 
-def infer_int(node, context=None):
-    """Infer int() calls
+def infer_int(node, context: InferenceContext | None = None):
+    """Infer int() calls.
 
     :param nodes.Call node: int() call to infer
     :param context.InferenceContext: node context
@@ -828,8 +826,8 @@ def infer_int(node, context=None):
     return nodes.Const(0)
 
 
-def infer_dict_fromkeys(node, context=None):
-    """Infer dict.fromkeys
+def infer_dict_fromkeys(node, context: InferenceContext | None = None):
+    """Infer dict.fromkeys.
 
     :param nodes.Call node: dict.fromkeys() call to infer
     :param context.InferenceContext context: node context
@@ -954,8 +952,11 @@ def _infer_str_format_call(
 
     try:
         formatted_string = format_template.format(*pos_values, **keyword_values)
-    except (IndexError, KeyError):
-        # If there is an IndexError there are too few arguments to interpolate
+    except (AttributeError, IndexError, KeyError, TypeError, ValueError):
+        # AttributeError: named field in format string was not found in the arguments
+        # IndexError: there are too few arguments to interpolate
+        # TypeError: Unsupported format string
+        # ValueError: Unknown format code
         return iter([util.Uninferable])
 
     return iter([nodes.const_factory(formatted_string)])
